==> nextcloud-app-spreed-1%3a9.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/nb.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Varighet %s)",
    "You attended a call with {user1}" : "Du har tatt del i en samtale med {user1}",
    "_%n guest_::_%n guests_" : ["%n gjest","%n gjester"],
    "You attended a call with {user1} and {user2}" : "Du har tatt del i en samtale med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du har tatt del i en samtale med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["én annen person","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterte deg til {call}",
    "Talk" : "Samtale",
    "Guest" : "Gjest",
    "Talk to %s" : "Snakk med %s",
    "Join call" : "Ta del i samtale",
    "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
    "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
    "Open settings" : "Åpne innstillinger",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "De forente arabiske emirater",
    "Afghanistan" : "Afganistan",
    "Anguilla" : "Angola",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Østerike",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Bosnia and Herzegovina" : "Bosnia og Hersegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Botswana" : "Botswana",
    "Belarus" : "Hviterusland",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Sveits",
    "Chile" : "Chile",
    "Cameroon" : "Kameron",
    "China" : "Kina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Kypros",
    "Denmark" : "Danmark",
    "Algeria" : "Algeri",
    "Spain" : "Spania",
    "Croatia" : "Kroatia",
    "Iraq" : "Irak",
    "Iceland" : "Island",
    "Italy" : "Italia",
    "Cambodia" : "Kambodia",
    "Sri Lanka" : "Sri Lanka",
    "Norway" : "Norge",
    "Serbia" : "Serbia",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Thailand" : "Thailand",
    "Tonga" : "Tonga",
    "Trinidad and Tobago" : "Trinidad og Tobago",
    "Uganda" : "Uganda",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Leave call" : "Forlat samtalen",
    "Limit to groups" : "Begrens til grupper",
    "Everyone" : "Alle",
    "Save changes" : "Lagre endringer",
    "Saving …" : "Lagrer...",
    "Saved!" : "Lagret!",
    "None" : "Ingen",
    "User" : "Bruker",
    "Disabled" : "Deaktivert",
    "Users" : "Brukere",
    "Name" : "Navn",
    "General settings" : "Generelle innstillinger",
    "Off" : "ett kvarter",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Opprettet den",
    "Pending" : "Venter",
    "Error" : "Feil",
    "Blocked" : "Blokkert",
    "Expired" : "Utløpt",
    "Signaling server URL" : "Sender signal til servers URL",
    "Validate SSL certificate" : "Bekreft SSL-sertifikat",
    "Saved" : "Lagret",
    "Shared secret" : "Delt hemmelighet",
    "STUN server URL" : "STUN server URL",
    "STUN servers" : "STUN-server",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
    "TURN server protocols" : "TURN-serverprotokoller",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "Copy link" : "Kopier lenke",
    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
    "Show your screen" : "Vis din skjerm",
    "Stop screensharing" : "Stopp skjermdeling",
    "Dismiss" : "Forkast",
    "No audio" : "Ingen lyd",
    "Mute audio (m)" : "Slå av lyd (m)",
    "Unmute audio (m)" : "Slå på lyd (m)",
    "Mute audio" : "Slå av lyd",
    "Disable video (v)" : "Skru av video (v)",
    "Enable video (v)" : "Skru på video (v)",
    "Disable video" : "Skru av video",
    "Enable video" : "Skru på video",
    "Screensharing options" : "Skjermdelingsvalg",
    "Enable screensharing" : "Skru på skjermdeling",
    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
    "You" : "Du",
    "Show screen" : "Vis skjerm",
    "Favorite" : "Merk som favoritt",
    "Leave conversation" : "Forlat samtale",
    "Delete conversation" : "Slett samtale",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "Conversations" : "Samtaler",
    "Loading" : "Laster",
    "Groups" : "Grupper",
    "Circles" : "Sirkler",
    "Password protect" : "Passordbeskyttelse",
    "Back" : "Tilbake",
    "Close" : "Lukk",
    "Conversation name" : "Samtalenavn",
    "Reply" : "Svar",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Send melding",
    "moderator" : "moderator",
    "guest" : "gjest",
    "Demote from moderator" : "Fjern moderatorstatus",
    "Promote to moderator" : "Gi moderatorstatus",
    "Remove participant" : "Fjern deltaker",
    "No results" : "Ingen resultater",
    "Add users or groups" : "Legg til bruker eller gruppe",
    "Participants" : "Deltakere",
    "Chat" : "Sludre",
    "Projects" : "Prosjekter",
    "Settings" : "Innstillinger",
    "Edit" : "Rediger",
    "Start call" : "Start samtale",
    "Rename conversation" : "Endre navn på samtale",
    "Share link" : "Del lenke",
    "Password protection" : "Passordbeskyttelse",
    "Enter a password" : "Skriv inn et passord",
    "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
    "Fullscreen (f)" : "Fullskjermsvisning (f)",
    "Grid view" : "Rutenett-visning",
    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
    "Password" : "Passord",
    "TURN server" : "TURN-server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-serveren fungerer som mellomserver for trafikk fra deltakere bak en brannmur.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "New conversation …" : "Ny samtale…",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "Please enter the password for this call" : "Skriv inn passordet for denne samtalen",
    "Password required" : "Passord kreves",
    "Cancel" : "Avbryt",
    "Submit" : "Send inn",
    "Guests" : "Gjester",
    "Change password" : "Endre passord",
    "Set password" : "Velg passord",
    "Rename" : "Gi nytt navn",
    "Link copied!" : "Lenke kopiert!",
    "Conversation with {name}" : "Samtale med {name}",
    "Error occurred while setting password" : "Feil oppstod ved setting av passord",
    "No messages yet, start the conversation!" : "Ingen meldinger enda, start samtalen!",
    "New message …" : "Ny melding …",
    "Send" : "Send",
    "Share" : "Del",
    "[Unknown user name]" : "[Ukjent brukernavn]",
    "Error occurred while sending message" : "Feil oppstod under foresendelse av melding",
    "Error while sharing" : "En feil har oppstått under deling",
    "No other people in this call" : "Ingen andre personer i denne samtalen",
    "Waiting for {participantName} to join the call …" : "Venter på at {participantName} skal bli med i samtalen…",
    "WebRTC is not supported in your browser :-/" : "WebRTC støttes ikke av din nettleser :-/",
    "Waiting for camera and microphone permissions" : "Venter på kamera- og mikrofon-tilganger",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Gi nettleseren tilgang til å bruke kamera og mikrofon for å kunne bruke denne appen.",
    "Share screen" : "Del skjerm",
    "No Camera" : "Inget kamera",
    "Screensharing is not supported by your browser." : "Skjermdeling støttes ikke av din nettleser.",
    "Add participant …" : "Legg til deltager…",
    "Favorited" : "Favorisert",
    "Your screen" : "Din skjerm",
    "{participantName}'s screen" : "{participantName}'s skjerm",
    "Guest's screen" : "Gjestens skjerm",
    "Contacts" : "Kontakter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3a9.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/nb.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(Varighet %s)",
    "You attended a call with {user1}" : "Du har tatt del i en samtale med {user1}",
    "_%n guest_::_%n guests_" : ["%n gjest","%n gjester"],
    "You attended a call with {user1} and {user2}" : "Du har tatt del i en samtale med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du har tatt del i en samtale med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du har tatt del i en samtale med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["én annen person","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterte deg til {call}",
    "Talk" : "Samtale",
    "Guest" : "Gjest",
    "Talk to %s" : "Snakk med %s",
    "Join call" : "Ta del i samtale",
    "{user} wants to talk with you" : "{user} ønsker å snakke med deg",
    "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
    "Open settings" : "Åpne innstillinger",
    "Conversations" : "Samtaler",
    "Messages" : "Meldinger",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "De forente arabiske emirater",
    "Afghanistan" : "Afganistan",
    "Anguilla" : "Angola",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Østerike",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Bosnia and Herzegovina" : "Bosnia og Hersegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgia",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Botswana" : "Botswana",
    "Belarus" : "Hviterusland",
    "Canada" : "Kanada",
    "Congo" : "Kongo",
    "Switzerland" : "Sveits",
    "Chile" : "Chile",
    "Cameroon" : "Kameron",
    "China" : "Kina",
    "Colombia" : "Kolombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Kypros",
    "Denmark" : "Danmark",
    "Algeria" : "Algeri",
    "Spain" : "Spania",
    "Croatia" : "Kroatia",
    "Iraq" : "Irak",
    "Iceland" : "Island",
    "Italy" : "Italia",
    "Cambodia" : "Kambodia",
    "Sri Lanka" : "Sri Lanka",
    "Norway" : "Norge",
    "Serbia" : "Serbia",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenia",
    "Svalbard and Jan Mayen" : "Svalbard og Jan Mayen",
    "Slovakia" : "Slovakia",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Thailand" : "Thailand",
    "Tonga" : "Tonga",
    "Trinidad and Tobago" : "Trinidad og Tobago",
    "Uganda" : "Uganda",
    "Invalid date, date format must be YYYY-MM-DD" : "Feil dato, dato må være i formatet YYYY-MM-DD",
    "Leave call" : "Forlat samtalen",
    "Limit to groups" : "Begrens til grupper",
    "Everyone" : "Alle",
    "Save changes" : "Lagre endringer",
    "Saving …" : "Lagrer...",
    "Saved!" : "Lagret!",
    "None" : "Ingen",
    "User" : "Bruker",
    "Disabled" : "Deaktivert",
    "Users" : "Brukere",
    "Beta" : "Beta",
    "Name" : "Navn",
    "General settings" : "Generelle innstillinger",
    "Off" : "ett kvarter",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Opprettet den",
    "Pending" : "Venter",
    "Error" : "Feil",
    "Blocked" : "Blokkert",
    "Active" : "Aktiv",
    "Expired" : "Utløpt",
    "Validate SSL certificate" : "Bekreft SSL-sertifikat",
    "Saved" : "Lagret",
    "Shared secret" : "Delt hemmelighet",
    "STUN server URL" : "STUN server URL",
    "STUN servers" : "STUN-server",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
    "TURN server protocols" : "TURN-serverprotokoller",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "Copy link" : "Kopier lenke",
    "Waiting for others to join the call …" : "Venter på at andre blir med i samtalen…",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
    "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
    "Show your screen" : "Vis din skjerm",
    "Stop screensharing" : "Stopp skjermdeling",
    "Dismiss" : "Forkast",
    "No audio" : "Ingen lyd",
    "Mute audio (m)" : "Slå av lyd (m)",
    "Unmute audio (m)" : "Slå på lyd (m)",
    "Mute audio" : "Slå av lyd",
    "Disable video (v)" : "Skru av video (v)",
    "Enable video (v)" : "Skru på video (v)",
    "Disable video" : "Skru av video",
    "Enable video" : "Skru på video",
    "Screensharing options" : "Skjermdelingsvalg",
    "Enable screensharing" : "Skru på skjermdeling",
    "Back" : "Tilbake",
    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
    "You" : "Du",
    "Show screen" : "Vis skjerm",
    "Favorite" : "Merk som favoritt",
    "Leave conversation" : "Forlat samtale",
    "Delete conversation" : "Slett samtale",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "Loading" : "Laster",
    "Groups" : "Grupper",
    "Circles" : "Sirkler",
    "Settings" : "Innstillinger",
    "Password protect" : "Passordbeskyttelse",
    "Close" : "Lukk",
    "Conversation name" : "Samtalenavn",
    "Camera" : "Kamera",
    "Reply" : "Svar",
    "Remove" : "Fjern",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Send melding",
    "Invalid path selected" : "Ugyldig angitt sti",
    "Enabled" : "Aktivert",
    "Save" : "Lagre",
    "Password" : "Passord",
    "API token" : "API-symbol",
    "Login" : "Logg inn",
    "Nickname" : "Kallenavn",
    "Client ID" : "Klient-ID",
    "moderator" : "moderator",
    "guest" : "gjest",
    "Demote from moderator" : "Fjern moderatorstatus",
    "Promote to moderator" : "Gi moderatorstatus",
    "Remove participant" : "Fjern deltaker",
    "No results" : "Ingen resultater",
    "Add users or groups" : "Legg til bruker eller gruppe",
    "Participants" : "Deltakere",
    "Chat" : "Sludre",
    "Edit" : "Rediger",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Search" : "Søk",
    "Start call" : "Start samtale",
    "Rename conversation" : "Endre navn på samtale",
    "Share link" : "Del lenke",
    "Password protection" : "Passordbeskyttelse",
    "Enter a password" : "Skriv inn et passord",
    "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
    "Fullscreen (f)" : "Fullskjermsvisning (f)",
    "Grid view" : "Rutenett-visning",
    "Start a conversation" : "Start en samtale",
    "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
    "Default" : "Standard",
    "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
    "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
    "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
    "WebRTC is not supported in your browser" : "WebRTC er ikke støttet av din nettleser",
    "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
    "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
    "TURN server" : "TURN-server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-serveren fungerer som mellomserver for trafikk fra deltakere bak en brannmur.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
    "Android app" : "Android-app",
    "iOS app" : "iOS-app",
    "New conversation …" : "Ny samtale…",
    "Projects" : "Prosjekter",
    "Copy" : "Kopier",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "Please enter the password for this call" : "Skriv inn passordet for denne samtalen",
    "Password required" : "Passord kreves",
    "Cancel" : "Avbryt",
    "Submit" : "Send inn",
    "Guests" : "Gjester",
    "Webinar" : "Webinar",
    "Change password" : "Endre passord",
    "Set password" : "Velg passord",
    "Rename" : "Gi nytt navn",
    "Link copied!" : "Lenke kopiert!",
    "Conversation with {name}" : "Samtale med {name}",
    "Error occurred while setting password" : "Feil oppstod ved setting av passord",
    "No messages yet, start the conversation!" : "Ingen meldinger enda, start samtalen!",
    "New message …" : "Ny melding …",
    "Send" : "Send",
    "Share" : "Del",
    "[Unknown user name]" : "[Ukjent brukernavn]",
    "Error occurred while sending message" : "Feil oppstod under foresendelse av melding",
    "Error while sharing" : "En feil har oppstått under deling",
    "No other people in this call" : "Ingen andre personer i denne samtalen",
    "Waiting for {participantName} to join the call …" : "Venter på at {participantName} skal bli med i samtalen…",
    "WebRTC is not supported in your browser :-/" : "WebRTC støttes ikke av din nettleser :-/",
    "Waiting for camera and microphone permissions" : "Venter på kamera- og mikrofon-tilganger",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Gi nettleseren tilgang til å bruke kamera og mikrofon for å kunne bruke denne appen.",
    "Share screen" : "Del skjerm",
    "No Camera" : "Inget kamera",
    "Screensharing is not supported by your browser." : "Skjermdeling støttes ikke av din nettleser.",
    "Add participant …" : "Legg til deltager…",
    "Favorited" : "Favorisert",
    "Your screen" : "Din skjerm",
    "{participantName}'s screen" : "{participantName}'s skjerm",
    "Guest's screen" : "Gjestens skjerm",
    "Limit app usage to groups." : "Begrens app-bruk til grupper",
    "Contacts" : "Kontakter",
    "Signaling server URL" : "Sender signal til servers URL"
},
"nplurals=2; plural=(n != 1);");
